function [output, support_out] = sig_nosig(input)
% function [output, support_out] = sig_nosig(input)
%
% SIG_NOSIG -- An implementation of the signal/no signal detector
%              See Lab #1 Section 1.2.5 for details
%
% Input Parameters:
%   input  -- a signal to be labeled signal/no signal
%
% Output Parameters:
%   output -- vector of 0/1 detection results for each block of the signal
%   support_out -- a vector that contains the sample number that begins each block

% Written by Mark Bartsch, Winter 2002
% Modification History:
%	8/16/02  --  Added modification history (MB)
%	1/1/03 -- renamed "x_axis" to "support_out" to match lab manual (JF)



% Define a block size:
block_size = ?

% Define a threshold:
threshold = ?

% Calculate the number of blocks:
number_of_blocks = ?

% Define your support_out:
support_out = ?

% For each block of the signal:
%   - Calculate the RMS value of the block
%   - Compare the RMS value to a threshold
%   - Store the result in an array called "output"
